@@ -1,7 +1,7 @@
 #
 package Pod::Weaver::Plugin::Include::Finder;
 
-our $VERSION = 'v0.1.6';
+our $VERSION = 'v0.1.7';
 
 our $VERSION = 'v0.1.901';
 
@@ -293,7 +293,7 @@ Pod::Weaver::Plugin::Include::Finder - Finds source Pods in .pod files or module
 
 =head1 VERSION
 
-version v0.1.6
+version v0.1.7
 
 =head1 SYNOPSIS
 
@@ -397,6 +397,23 @@ If a template is missing in the C<cache> then tries to C<load_file()>.
 
 Returns I<undef> if failed.
 
+=head2 init_cache
+
+Initializer for cache attribute.
+
+=head2 init_maps
+
+Initilizer for maps attribute.
+
+=head2 init_pod_path
+
+Initializer for pod_path attribute.
+
+=head2 init_logger
+
+Initializer for logger attribute. Takes logger object either from
+callerPlugin or creates a new one.
+
 =head1 PRIVATE ATTRIBUTES
 
 =head2 B<_tmplSource, _tmplName, _tmplContent>
